@@ -8,6 +8,7 @@ import os
 import sys
 import json
 import traceback
+from typing import Tuple
 
 _resources_dir = 'resources'
 _licenses_json_file = 'licenses.json'
@@ -20,7 +21,7 @@ def get_license_from_nick():
     licenses_file = os.path.join(_resources_dir, _frequent_lic_nick_json_file)
 
     try:
-        base_dir = sys._MEIPASS
+        base_dir = os.path.join(sys._MEIPASS, vars(sys.modules[__name__])['__package__'])
     except Exception:
         base_dir = os.path.dirname(__file__)
 
@@ -34,7 +35,7 @@ def get_license_from_nick():
     return licenses
 
 
-def get_spdx_licenses_json():
+def get_spdx_licenses_json() -> Tuple[bool, str, str]:
     success = True
     error_msg = ''
     licenses = ''
@@ -42,7 +43,7 @@ def get_spdx_licenses_json():
     licenses_file = os.path.join(_resources_dir, _licenses_json_file)
 
     try:
-        base_dir = sys._MEIPASS
+        base_dir = os.path.join(sys._MEIPASS, vars(sys.modules[__name__])['__package__'])
     except Exception:
         base_dir = os.path.dirname(__file__)
 
